# If any of the following macros should be set otherwise,
# you can wrap any of them with the following conditions:
# - %%if 0%%{centos} == 7
# - %%if 0%%{?rhel} == 7
# - %%if 0%%{?fedora} == 23
# Or just test for particular distribution:
# - %%if 0%%{centos}
# - %%if 0%%{?rhel}
# - %%if 0%%{?fedora}
#
# Be aware, on centos, both %%rhel and %%centos are set. If you want to test
# rhel specific macros, you can use %%if 0%%{?rhel} && 0%%{?centos} == 0 condition.
# (Don't forget to replace double percentage symbol with single one in order to apply a condition)

# Generate devel rpm
%global with_devel 1
# Build project from bundled dependencies
%global with_bundled 0
# Build with debug info rpm
%global with_debug 0
# Run tests in check section
%global with_check 1
# Generate unit-test rpm
%global with_unit_test 0

%if 0%{?with_debug}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package   %{nil}
%endif

%if ! 0%{?gobuild:1}
%define gobuild(o:) go build -ldflags "${LDFLAGS:-} -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n')" -a -v -x %{?**};
%endif

%global provider        github
%global provider_tld    com
%global project         skyrings
%global repo            skyring-common
# https://github.com/skyrings/skyring-common
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}
%global commit          d1c0bb1cbd5ed8438be1385c85c4f494608cde1e
%global shortcommit     %(c=%{commit}; echo ${c:0:7})

Name:           golang-%{provider}-%{project}-%{repo}
Version:        0
Release:        0.1.git%{shortcommit}%{?dist}
Summary:        Provides common frameworks like logger, task management to be used by skyring & storage providers 
License:        ASL 2.0
URL:            https://%{provider_prefix}
Source0:        https://%{provider_prefix}/archive/%{commit}/%{repo}-%{shortcommit}.tar.gz

# e.g. el6 has ppc64 arch without gcc-go, so EA tag is required
ExclusiveArch:  %{?go_arches:%{go_arches}}%{!?go_arches:%{ix86} x86_64 aarch64 %{arm}}
# If go_compiler is not set to 1, there is no virtual provide. Use golang instead.
BuildRequires:  %{?go_compiler:compiler(go-compiler)}%{!?go_compiler:golang}

%if ! 0%{?with_bundled}
# Remaining dependencies not included in main packages
BuildRequires: golang(gopkg.in/mgo.v2/bson)
BuildRequires: golang(github.com/parnurzeal/gorequest)
BuildRequires: golang(github.com/influxdb/influxdb/client)
BuildRequires: golang(golang.org/x/crypto/ssh)
BuildRequires: golang(github.com/marpaia/graphite-golang)
BuildRequires: golang(github.com/sbinet/go-python)
BuildRequires: golang(github.com/op/go-logging)
BuildRequires: golang(gopkg.in/mgo.v2)
%endif

%description
%{summary}

%if 0%{?with_devel}
%package devel
Summary:       %{summary}
BuildArch:     noarch

%if 0%{?with_check} && ! 0%{?with_bundled}
BuildRequires: golang(github.com/influxdb/influxdb/client)
BuildRequires: golang(github.com/marpaia/graphite-golang)
BuildRequires: golang(github.com/op/go-logging)
BuildRequires: golang(github.com/parnurzeal/gorequest)
BuildRequires: golang(github.com/sbinet/go-python)
BuildRequires: golang(golang.org/x/crypto/ssh)
BuildRequires: golang(gopkg.in/mgo.v2)
BuildRequires: golang(gopkg.in/mgo.v2/bson)
%endif

Requires:      golang(github.com/influxdb/influxdb/client)
Requires:      golang(github.com/marpaia/graphite-golang)
Requires:      golang(github.com/op/go-logging)
Requires:      golang(github.com/parnurzeal/gorequest)
Requires:      golang(github.com/sbinet/go-python)
Requires:      golang(golang.org/x/crypto/ssh)
Requires:      golang(gopkg.in/mgo.v2)
Requires:      golang(gopkg.in/mgo.v2/bson)

Provides:      golang(%{import_path}/conf) = %{version}-%{release}
Provides:      golang(%{import_path}/dao) = %{version}-%{release}
Provides:      golang(%{import_path}/db) = %{version}-%{release}
Provides:      golang(%{import_path}/dbprovider) = %{version}-%{release}
Provides:      golang(%{import_path}/dbprovider/mongodb) = %{version}-%{release}
Provides:      golang(%{import_path}/event) = %{version}-%{release}
Provides:      golang(%{import_path}/models) = %{version}-%{release}
Provides:      golang(%{import_path}/monitoring) = %{version}-%{release}
Provides:      golang(%{import_path}/monitoring/graphitemanager) = %{version}-%{release}
Provides:      golang(%{import_path}/monitoring/influxdbmanager) = %{version}-%{release}
Provides:      golang(%{import_path}/notifier) = %{version}-%{release}
Provides:      golang(%{import_path}/provisioner) = %{version}-%{release}
Provides:      golang(%{import_path}/provisioner/cephinstaller) = %{version}-%{release}
Provides:      golang(%{import_path}/tools/crypto) = %{version}-%{release}
Provides:      golang(%{import_path}/tools/gopy) = %{version}-%{release}
Provides:      golang(%{import_path}/tools/lock) = %{version}-%{release}
Provides:      golang(%{import_path}/tools/logger) = %{version}-%{release}
Provides:      golang(%{import_path}/tools/schedule) = %{version}-%{release}
Provides:      golang(%{import_path}/tools/ssh) = %{version}-%{release}
Provides:      golang(%{import_path}/tools/task) = %{version}-%{release}
Provides:      golang(%{import_path}/tools/uuid) = %{version}-%{release}
Provides:      golang(%{import_path}/utils) = %{version}-%{release}

%description devel
%{summary}

This package contains library source intended for
building other packages which use import path with
%{import_path} prefix.
%endif

%if 0%{?with_unit_test} && 0%{?with_devel}
%package unit-test-devel
Summary:         Unit tests for %{name} package
%if 0%{?with_check}
#Here comes all BuildRequires: PACKAGE the unit tests
#in %%check section need for running
%endif

# test subpackage tests code from devel subpackage
Requires:        %{name}-devel = %{version}-%{release}

%if 0%{?with_check} && ! 0%{?with_bundled}
%endif


%description unit-test-devel
%{summary}

This package contains unit tests for project
providing packages with %{import_path} prefix.
%endif

%prep
%setup -q -n %{repo}-%{commit}

%build
mkdir -p src/%{provider}.%{provider_tld}/%{project}
ln -s ../../../ src/%{import_path}

%if ! 0%{?with_bundled}
export GOPATH=$(pwd):%{gopath}
%else
# No dependency directories so far
export GOPATH=$(pwd):%{gopath}
%endif


%install
install -d -p %{buildroot}%{_bindir}

# source codes for building projects
%if 0%{?with_devel}
install -d -p %{buildroot}/%{gopath}/src/%{import_path}/
echo "%%dir %%{gopath}/src/%%{import_path}/." >> devel.file-list
# find all *.go but no *_test.go files and generate devel.file-list
for file in $(find . \( -iname "*.go" -or -iname "*.s" \) \! -iname "*_test.go") ; do
    dirprefix=$(dirname $file)
    install -d -p %{buildroot}/%{gopath}/src/%{import_path}/$dirprefix
    cp -pav $file %{buildroot}/%{gopath}/src/%{import_path}/$file
    echo "%%{gopath}/src/%%{import_path}/$file" >> devel.file-list

    while [ "$dirprefix" != "." ]; do
        echo "%%dir %%{gopath}/src/%%{import_path}/$dirprefix" >> devel.file-list
        dirprefix=$(dirname $dirprefix)
    done
done
%endif

# testing files for this project
%if 0%{?with_unit_test} && 0%{?with_devel}
install -d -p %{buildroot}/%{gopath}/src/%{import_path}/
# find all *_test.go files and generate unit-test-devel.file-list
for file in $(find . -iname "*_test.go") ; do
    dirprefix=$(dirname $file)
    install -d -p %{buildroot}/%{gopath}/src/%{import_path}/$dirprefix
    cp -pav $file %{buildroot}/%{gopath}/src/%{import_path}/$file
    echo "%%{gopath}/src/%%{import_path}/$file" >> unit-test-devel.file-list

    while [ "$dirprefix" != "." ]; do
        echo "%%dir %%{gopath}/src/%%{import_path}/$dirprefix" >> devel.file-list
        dirprefix=$(dirname $dirprefix)
    done
done
%endif

%if 0%{?with_devel}
sort -u -o devel.file-list devel.file-list
%endif

%check
%if 0%{?with_check} && 0%{?with_unit_test} && 0%{?with_devel}
%if ! 0%{?with_bundled}
export GOPATH=%{buildroot}/%{gopath}:%{gopath}
%else
# No dependency directories so far

export GOPATH=%{buildroot}/%{gopath}:%{gopath}
%endif

%if ! 0%{?gotest:1}
%global gotest go test
%endif

%endif

#define license tag if not already defined
%{!?_licensedir:%global license %doc}

%files
%license LICENSE
%doc README.md

%if 0%{?with_devel}
%files devel -f devel.file-list
%license LICENSE
%doc README.md
%dir %{gopath}/src/%{provider}.%{provider_tld}/%{project}
%endif

%if 0%{?with_unit_test} && 0%{?with_devel}
%files unit-test-devel -f unit-test-devel.file-list
%license LICENSE
%doc README.md
%endif

%changelog
* Sat Feb 04 2017 Tom Callaway <spot@fedoraproject.org> - 0-0.1.gitd1c0bb1
- First package for Fedora

